﻿using AutoMapper;
using COA.EnterpriseServices.DataAccess.Helpers;
using StructureMap;

namespace COA.EnterpriseServices.DataAccess
{
    public static class Dependencies
    {
        public static IContainer Container { get; }

        static Dependencies()
        {
            Container = new Container(c =>
            {
                c.Scan(s =>
                {
                    s.AddAllTypesOf(typeof(IDataAccess<>));
                    s.AddAllTypesOf(typeof(DataAccessManager<>));

                    s.WithDefaultConventions();
                    s.AssembliesFromApplicationBaseDirectory();
                });

                c.For(typeof(IDataAccess<>)).Singleton();
                c.For(typeof(DataAccessManager<>)).Singleton();

                c.For<IMapper>().Singleton().Use(() => Mapping.GetMapper());

                c.For<ClientHelper>().Singleton();
                c.For<CreditorHelper>().Singleton();
            });
        }
    }
}
